@@ -187,18 +187,19 @@ class Project(AbstractApiClass):
         """
         return self.client.list_project_feature_groups(self.project_id, filter_feature_group_use)
 
-    def list_feature_group_templates(self, limit: int = 100, start_after_id: str = None):
+    def list_feature_group_templates(self, limit: int = 100, start_after_id: str = None, should_include_all_system_templates: bool = False):
         """
         List feature group templates for feature groups associated with the project.
 
         Args:
             limit (int): The maximum number of templates to be retrieved.
             start_after_id (str): An offset parameter to exclude all templates till the specified feature group template ID.
+            should_include_all_system_templates (bool): 
 
         Returns:
             FeatureGroupTemplate: All the feature groups in the organization, optionally limited by the feature group that created the template(s).
         """
-        return self.client.list_project_feature_group_templates(self.project_id, limit, start_after_id)
+        return self.client.list_project_feature_group_templates(self.project_id, limit, start_after_id, should_include_all_system_templates)
 
     def get_training_config_options(self, feature_group_ids: list = None, for_retrain: bool = False):
         """
@@ -216,7 +217,7 @@ class Project(AbstractApiClass):
         """
         return self.client.get_training_config_options(self.project_id, feature_group_ids, for_retrain)
 
-    def train_model(self, name: str = None, training_config: dict = None, feature_group_ids: list = None, refresh_schedule: str = None, custom_algorithms_only: bool = False):
+    def train_model(self, name: str = None, training_config: dict = None, feature_group_ids: list = None, refresh_schedule: str = None, custom_algorithms: list = None, custom_algorithms_only: bool = False, custom_algorithm_configs: dict = None, cpu_size: str = None, memory: int = None):
         """
         Trains a model for the specified project.
 
@@ -228,12 +229,16 @@ class Project(AbstractApiClass):
             training_config (dict): The training config key/value pairs used to train this model.
             feature_group_ids (list): List of feature group ids provided by the user to train the model on.
             refresh_schedule (str): A cron-style string that describes a schedule in UTC to automatically retrain the created model.
+            custom_algorithms (list): List of user-defined algorithms to train.
             custom_algorithms_only (bool): Whether only run custom algorithms.
+            custom_algorithm_configs (dict): Configs for each user-defined algorithm, key is algorithm name, value is the config serialized to json
+            cpu_size (str): Size of the cpu for the user-defined algorithms during train.
+            memory (int): Memory (in GB) for the user-defined algorithms during train.
 
         Returns:
             Model: The new model which is being trained.
         """
-        return self.client.train_model(self.project_id, name, training_config, feature_group_ids, refresh_schedule, custom_algorithms_only)
+        return self.client.train_model(self.project_id, name, training_config, feature_group_ids, refresh_schedule, custom_algorithms, custom_algorithms_only, custom_algorithm_configs, cpu_size, memory)
 
     def create_model_from_python(self, function_source_code: str, train_function_name: str, training_input_tables: list, predict_function_name: str = None, predict_many_function_name: str = None, initialize_function_name: str = None, name: str = None, cpu_size: str = None, memory: int = None, training_config: dict = None, exclusive_run: bool = False, package_requirements: dict = None):
         """
@@ -267,69 +272,6 @@ class Project(AbstractApiClass):
         """
         return self.client.create_model_from_python(self.project_id, function_source_code, train_function_name, training_input_tables, predict_function_name, predict_many_function_name, initialize_function_name, name, cpu_size, memory, training_config, exclusive_run, package_requirements)
 
-    def create_model_from_zip(self, train_function_name: str, train_module_name: str, predict_module_name: str, training_input_tables: list, predict_function_name: str = None, predict_many_function_name: str = None, name: str = None, cpu_size: str = None, memory: int = None, package_requirements: dict = None):
-        """
-        Initializes a new Model from a user provided zip file containing Python code. If a list of input feature groups are supplied,
-
-        we will provide as arguments to the train and predict functions with the materialized feature groups for those
-        input feature groups.
-
-        This method expects `trainModuleName` and `predictModuleName` to be valid language source files which contains the functions named
-        `trainFunctionName` and `predictFunctionName`, respectively. `trainFunctionName` returns the ModelVersion that is the result of
-        training the model using `trainFunctionName` and `predictFunctionName` has no well defined return type,
-        as it returns the prediction made by the `predictFunctionName`, which can be anything
-
-
-        Args:
-            train_function_name (str): Name of the function found in train module that will be executed to train the model. It is not executed when this function is run.
-            train_module_name (str): Full path of the module that contains the train function from the root of the zip.
-            predict_module_name (str): Full path of the module that contains the predict function from the root of the zip.
-            training_input_tables (list): List of feature groups that are supplied to the train function as parameters. Each of the parameters are materialized Dataframes (same type as the functions return value).
-            predict_function_name (str): Name of the function found in the predict module that will be executed run predictions through model. It is not executed when this function is run.
-            predict_many_function_name (str): Name of the function found in the predict module that will be executed run batch predictions through model. It is not executed when this function is run.
-            name (str): The name you want your model to have. Defaults to "<Project Name> Model".
-            cpu_size (str): Size of the cpu for the model training function
-            memory (int): Memory (in GB) for the model training function
-            package_requirements (dict): Json with key value pairs corresponding to package: version for each dependency
-
-        Returns:
-            Upload: None
-        """
-        return self.client.create_model_from_zip(self.project_id, train_function_name, train_module_name, predict_module_name, training_input_tables, predict_function_name, predict_many_function_name, name, cpu_size, memory, package_requirements)
-
-    def create_model_from_git(self, application_connector_id: str, branch_name: str, train_function_name: str, train_module_name: str, predict_module_name: str, training_input_tables: list, predict_function_name: str = None, predict_many_function_name: str = None, python_root: str = None, name: str = None, cpu_size: str = None, memory: int = None, package_requirements: dict = None):
-        """
-        Initializes a new Model from a user provided git repository containing Python code. If a list of input feature groups are supplied,
-
-        we will provide as arguments to the train and predict functions with the materialized feature groups for those
-        input feature groups.
-
-        This method expects `trainModuleName` and `predictModuleName` to be valid language source files which contains the functions named
-        `trainFunctionName` and `predictFunctionName`, respectively. `trainFunctionName` returns the ModelVersion that is the result of
-        training the model using `trainFunctionName` and `predictFunctionName` has no well defined return type,
-        as it returns the prediction made by the `predictFunctionName`, which can be anything
-
-
-        Args:
-            application_connector_id (str): The unique ID associated with the git application connector.
-            branch_name (str): Name of the branch in the git repository to be used for training.
-            train_function_name (str): Name of the function found in train module that will be executed to train the model. It is not executed when this function is run.
-            train_module_name (str): Full path of the module that contains the train function from the root of the zip.
-            predict_module_name (str): Full path of the module that contains the predict function from the root of the zip.
-            training_input_tables (list): List of feature groups that are supplied to the train function as parameters. Each of the parameters are materialized Dataframes (same type as the functions return value).
-            predict_function_name (str): Name of the function found in the predict module that will be executed run predictions through model. It is not executed when this function is run.
-            predict_many_function_name (str): 
-            python_root (str): Path from the top level of the git repository to the directory containing the Python source code. If not provided, the default is the root of the git repository.
-            name (str): The name you want your model to have. Defaults to "<Project Name> Model".
-            cpu_size (str): Size of the cpu for the model training function
-            memory (int): Memory (in GB) for the model training function
-            package_requirements (dict): Json with key value pairs corresponding to package: version for each dependency
-
-        Returns:
-            Model: None
-        """
-        return self.client.create_model_from_git(self.project_id, application_connector_id, branch_name, train_function_name, train_module_name, predict_module_name, training_input_tables, predict_function_name, predict_many_function_name, python_root, name, cpu_size, memory, package_requirements)
-
     def list_models(self):
         """
         Retrieves the list of models in the specified project.
@@ -342,20 +284,22 @@ class Project(AbstractApiClass):
         """
         return self.client.list_models(self.project_id)
 
-    def get_custom_train_function_info(self, feature_group_names_for_training: list = None, training_data_parameter_name_override: dict = None):
+    def get_custom_train_function_info(self, feature_group_names_for_training: list = None, training_data_parameter_name_override: dict = None, training_config: dict = None, custom_algorithm_config: dict = None):
         """
         Returns the information about how to call the custom train function.
 
         Args:
             feature_group_names_for_training (list): A list of feature group table names that will be used for training
             training_data_parameter_name_override (dict): Override from feature group type to parameter name in train function.
+            training_config (dict): Training config names to values for the options supported by Abacus.ai platform.
+            custom_algorithm_config (dict): User-defined config that can be serialized by JSON.
 
         Returns:
             CustomTrainFunctionInfo: Information about how to call the customer provided train function.
         """
-        return self.client.get_custom_train_function_info(self.project_id, feature_group_names_for_training, training_data_parameter_name_override)
+        return self.client.get_custom_train_function_info(self.project_id, feature_group_names_for_training, training_data_parameter_name_override, training_config, custom_algorithm_config)
 
-    def create_model_monitor(self, training_feature_group_id: str, prediction_feature_group_id: str, name: str = None, refresh_schedule: str = None, target_value: str = None, feature_mappings: dict = None):
+    def create_model_monitor(self, training_feature_group_id: str, prediction_feature_group_id: str, name: str = None, refresh_schedule: str = None, target_value: str = None, feature_mappings: dict = None, model_id: str = None, training_feature_mappings: dict = None):
         """
         Runs a model monitor for the specified project.
 
@@ -366,11 +310,13 @@ class Project(AbstractApiClass):
             refresh_schedule (str): A cron-style string that describes a schedule in UTC to automatically retrain the created model monitor
             target_value (str): A target positive value for the label to compute bias for
             feature_mappings (dict): A json map to override features for prediction_feature_group, where keys are column names and the values are feature data use types.
+            model_id (str): The Unique ID of the Model
+            training_feature_mappings (dict): " A json map to override features for training_fature_group, where keys are column names and the values are feature data use types.
 
         Returns:
             ModelMonitor: The new model monitor that was created.
         """
-        return self.client.create_model_monitor(self.project_id, training_feature_group_id, prediction_feature_group_id, name, refresh_schedule, target_value, feature_mappings)
+        return self.client.create_model_monitor(self.project_id, training_feature_group_id, prediction_feature_group_id, name, refresh_schedule, target_value, feature_mappings, model_id, training_feature_mappings)
 
     def list_model_monitors(self):
         """
